# Introduction
This is a project designed to provide a number of functions related to parsing and processing earthquake ground motion data, building on top of the [ObsPy](https://github.com/obspy/obspy/wiki) library.
Most of the extensions that we provide are to handle strong motion data and related issues.


# Documentation
- Please note, we are in the process of improving the documentation and that there are some incomplete sections.
- The full documentation can be viewed locally by running the `doc_source/makedocs.sh` script.
- The documentation is also available [here](https://ghsc.code-pages.usgs.gov/esi/groundmotion-processing/).

# Getting Help
The developers can be reached at [gmprocess@usgs.gov](mailto:gmprocess@usgs.gov).

If you would like to post an issue to ask a question, request a new feature, or report a bug, you can do so at the [github mirror](https://github.com/DOI-USGS/ghsc-esi-groundmotion-processing) of this repository. 

If you would like to contribute merge requests to this repository, please let us know and we can add you as a collaborator. 
This will require that you create an account at code.usgs.gov, which is a more involved process than creating a personal account at gitub.com and posting to the issues on the github mirror.

# Reference
If you wish to cite this software, please use this reference:

- Hearne, M., E. M. Thompson, H. Schovanec, J. Rekoske, B. T. Aagaard, and C. B. Worden (2019). USGS automated ground motion processing software, USGS Software Release, doi: [10.5066/P9ANQXN3](https://dx.doi.org/10.5066/P9ANQXN3).
  